@@ -122,6 +122,12 @@ sub encode {
     return $self;
 }
 
+sub length {
+    my $self = shift;
+    $self->{bytestream} ||= '';
+    return length $self->{bytestream};
+}
+
 sub md5_sum {
     my $self = shift;
 
@@ -164,12 +170,6 @@ sub quote {
     return $self;
 }
 
-sub stream_length {
-    my $self = shift;
-    $self->{bytestream} ||= '';
-    return length $self->{bytestream};
-}
-
 sub to_string { return shift->{bytestream} }
 
 sub unquote {
@@ -266,7 +266,7 @@ Mojo::ByteStream - ByteStream
     $stream->url_sanitize;
     $stream->url_unescape;
 
-    my $stream_length = $stream->stream_length;
+    my $length = $stream->length;
 
     my $stream2 = $stream->clone;
     print $stream2->to_string;
@@ -281,12 +281,6 @@ Mojo::ByteStream - ByteStream
 L<Mojo::ByteStream> provides portable text and bytestream manipulation
 functions.
 
-=head1 ATTRIBUTES
-
-=head2 C<stream_length>
-
-    my $stream_length = $stream->stream_length;
-
 =head1 METHODS
 
 L<Mojo::ByteStream> inherits all methods from L<Mojo::Base> and implements
@@ -324,6 +318,10 @@ the following new ones.
 
     $stream = $stream->encode($encoding);
 
+=head2 C<length>
+
+    my $length = $stream->length;
+
 =head2 C<md5_sum>
 
     $stream = $stream->md5_sum;
