@@ -59,7 +59,7 @@ sub serve {
         $res->content(Mojo::Content->new(file => Mojo::File->new));
         $res->code(200);
         $res->headers->content_type($type);
-        $res->content->file->file_name($path);
+        $res->content->file->path($path);
     }
 
     return $self;
@@ -108,7 +108,7 @@ implements the follwing the ones.
 
     $dispatcher = $dispatcher->dispatch($tx);
 
-=head2 C<server>
+=head2 C<serve>
 
     $dispatcher = $dispatcher->serve($tx, '/foo/bar.html');
 
