@@ -33,6 +33,11 @@ sub run {
     my $path = $self->class_to_path($controller);
     $self->render_to_rel_file('controller', "$name/lib/$path", $controller);
 
+    # Context
+    my $context = "${class}::Context";
+    $path = $self->class_to_path($context);
+    $self->render_to_rel_file('context', "$name/lib/$path", $context);
+
     # Test
     $self->render_to_rel_file('test', "$name/t/basic.t", $class);
 
@@ -149,6 +154,9 @@ sub dispatch {
 sub startup {
     my $self = shift;
 
+    # Use our own context class
+    $self->ctx_class('<%= $class %>::Context');
+
     # Routes
     my $r = $self->routes;
 
@@ -175,6 +183,16 @@ sub welcome {
     $c->render;
 }
 
+1;
+__context__
+% my $class = shift;
+package <%= $class %>;
+
+use strict;
+use warnings;
+
+use base 'Mojolicious::Context';
+
 1;
 __static__
 <!doctype html>
@@ -217,7 +235,7 @@ __welcome__
     <body>
         <h2>Welcome to the Mojolicious Web Framework!</h2>
         This page was generated from the template
-        "templates/example/test.phtml",
+        "templates/example/welcome.phtml",
         <a href="<%= $c->url_for %>">
             click here
         </a> 
